==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ScalerParamsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScalerParamsDescription } from "./ScalerParamsDescription";
/**
 * @hidden
 */
export let ScalerParamsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScalerParamsDescriptionMetadata extends Base {
        static b(a) {
            if (ScalerParamsDescriptionMetadata.a == null) {
                ScalerParamsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScalerParamsDescriptionMetadata.c(ScalerParamsDescriptionMetadata.a);
            }
            if (a.j(ScalerParamsDescriptionMetadata.a)) {
                return;
            }
            a.y(ScalerParamsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ReferenceValue", "Number:double");
        }
        static d(a) {
            ScalerParamsDescriptionMetadata.b(a);
            a.aa("ScalerParams", () => new ScalerParamsDescription());
            a.z("ScalerParams", ScalerParamsDescriptionMetadata.a);
        }
    }
    ScalerParamsDescriptionMetadata.$t = /*@__PURE__*/ markType(ScalerParamsDescriptionMetadata, 'ScalerParamsDescriptionMetadata');
    ScalerParamsDescriptionMetadata.a = null;
    return ScalerParamsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ScalerParamsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScalerParamsDescription } from "./ScalerParamsDescription";
/**
 * @hidden
 */
export let ScalerParamsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScalerParamsDescriptionMetadata extends Base {
        static b(a) {
            if (ScalerParamsDescriptionMetadata.a == null) {
                ScalerParamsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScalerParamsDescriptionMetadata.c(ScalerParamsDescriptionMetadata.a);
            }
            if (a.k(ScalerParamsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ScalerParamsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ReferenceValue", "Number:double");
        }
        static d(a) {
            ScalerParamsDescriptionMetadata.b(a);
            a.ac("ScalerParams", () => new ScalerParamsDescription());
            a.ab("ScalerParams", ScalerParamsDescriptionMetadata.a);
        }
    }
    ScalerParamsDescriptionMetadata.$t = /*@__PURE__*/ markType(ScalerParamsDescriptionMetadata, 'ScalerParamsDescriptionMetadata');
    ScalerParamsDescriptionMetadata.a = null;
    return ScalerParamsDescriptionMetadata;
})();
